package game

import (
	"fmt"
	"sirlab.de/go/knyt/user"
)

func (gm *Game) EventPlayerJoins(usr *user.User) {
	usrId := usr.GetId()
	usrName := usr.GetName()

	gm.mu.Lock()
	defer gm.mu.Unlock()

	prevPlayer := gm.players[usrId]
	player := playerInfo{
		id:        usrId,
		name:      usrName,
		isPlaying: true,
		isIdle:    false,
		score:     prevPlayer.score,
	}
	gm.players[usrId] = player

	if prevPlayer.id != "" {
		fmt.Printf("player \"%s\" re-joined\n", gm.players[usrId].name)
	} else {
		fmt.Printf("player \"%s\" joined\n", usrName)
	}

	gm.eng.Update()
}

func (gm *Game) EventPlayerLeaves(usr *user.User) {
	usrId := usr.GetId()

	gm.mu.Lock()
	defer gm.mu.Unlock()

	player := gm.players[usrId]
	if player.id != usrId {
		return
	}
	player.isIdle = true
	gm.players[usrId] = player

	fmt.Printf("player \"%s\" is idle\n", usr.GetName())

	gm.eng.Update()
}

func (gm *Game) AddPlayer(usr *user.User) {
	usrId := usr.GetId()

	gm.mu.Lock()
	defer gm.mu.Unlock()

	player := gm.players[usrId]
	if player.id == usrId {
		return
	}

	gm.players[usrId] = playerInfo{
		id:        usrId,
		name:      usr.GetName(),
		isPlaying: false,
		isIdle:    true,
		score:     0,
	}
}
